from .core.decryptor import DummyDecoder, RSADecoder
from .core.encryptor import DummyEncoder, RSAEncoder
from .core.keys import pubkeyToBin, pubkeyFromBin
from rsa import newkeys

class Communicator():
    def __init__(self, sock, encoder, decoder):
        self.sock = sock
        self.encoder = encoder
        self.decoder = decoder

        key = self.encoder.key
        self._send(pubkeyToBin(key))

        self.encoder.key = pubkeyFromBin(self._recv())
    
    def _send(self, data):
        self.sock.sendall(int.to_bytes(len(data), 4, "little"))
        self.sock.sendall(data)
    
    def _recvData(self, size):
        received_payload = b""
        reamining_payload_size = size
        while reamining_payload_size != 0:
            received_payload += self.sock.recv(reamining_payload_size)
            reamining_payload_size = size - len(received_payload)
        return received_payload
    
    def _recv(self):
        size =  int.from_bytes(self.sock.recv(4), "little")
        return self._recvData(size)
    
    def send(self, data):
        data = self.encoder.encrypt(data)
        self._send(data)
    
    def recv(self):
        data = self._recv()
        print("length: ", len(data))
        return self.decoder.decrypt(data)


def createComunicator(sock, keySize):
    (pubkey, privkey) = newkeys(keySize)
    return Communicator(sock, RSAEncoder(pubkey), RSADecoder(privkey))



from distutils.core import setup
from setuptools import find_packages

with open("README.md", "r") as file:
    long_description = file.read()

setup(name='end2end',
      version='1.1.1',
      description='Python end two end encryption designed for socket',
      long_description=long_description,
      long_description_content_type='text/markdown',
      author='Julian Wandhoven',
      author_email='jwandhoven@gmail.com',
      url='https://github.com/JulianWww/end2end-encryption',
      packages=find_packages(include=['end2end']),
      license="MIT",
      install_requires = [
          "rsa"
      ],
      project_urls={
            "Bug Tracker": "https://github.com/JulianWww/end2end-encryption/issues",
            #"Documentation": get_docs_url(),
            "Source Code": "https://github.com/JulianWww/end2end-encryption",
        }
     )